# bindpyrame

Simple module in pure python3 to connect to pyrame http://llr.in2p3.fr/sites/pyrame/

Can be installed through pip on testpypi for now

     pip install -i https://test.pypi.org/simple/ bindpyrame-llr-online

The status of this package can be checked at https://test.pypi.org/project/bindpyrame-llr-online/


